@@ -74,8 +74,8 @@ class SyspassClient(syspassclient.Object, syspassclient.Utils, metaclass=Singlet
         self.__config = None
         self.config = syspassclient.config
         self.api_url = self.config.api_url
-        # self.authToken = self.config.authToken
-        # self.tokenPass = self.config.tokenPass
+        self.authToken = self.config.authToken
+        self.tokenPass = self.config.tokenPass
         self.debug = self.config.debug
         self.debug_level = self.config.debug_level
         self.verbose = self.config.verbose
